==> haskell-socks-0.6.1-335-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-socks.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 socks
version:              0.6.1
visibility:           public
id:                   socks-0.6.1-GPkRF25PXKE2VY5Hz73qin
key:                  socks-0.6.1-GPkRF25PXKE2VY5Hz73qin
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-socks
synopsis:             Socks proxy (ver 5)
description:          Socks proxy (version 5) implementation.
category:             Network
abi:                  92aab820d2a8d8e293ba35df9777db3f
exposed:              True
exposed-modules:
    Network.Socks5 Network.Socks5.Lowlevel Network.Socks5.Types

hidden-modules:
    Network.Socks5.Wire Network.Socks5.Conf Network.Socks5.Command
    Network.Socks5.Parse

import-dirs:          /usr/lib/ghc-9.6.6/site-local/socks-0.6.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/socks-0.6.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/socks-0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-socks
hs-libraries:         HSsocks-0.6.1-GPkRF25PXKE2VY5Hz73qin
depends:
    base-4.18.2.1 basement-0.0.16-HvTgG10TboKKpCgs2TlMDx
    bytestring-0.11.5.3 cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    network-3.1.4.0-IebBekr390i8Nw6inuvzzb

haddock-interfaces:   /usr/share/doc/haskell-socks/html/socks.haddock
haddock-html:         /usr/share/doc/haskell-socks/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-socks-0.6.1-336-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-socks.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 socks
version:              0.6.1
visibility:           public
id:                   socks-0.6.1-JuyQtPcZcFFLRHOWXu2EAp
key:                  socks-0.6.1-JuyQtPcZcFFLRHOWXu2EAp
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-socks
synopsis:             Socks proxy (ver 5)
description:          Socks proxy (version 5) implementation.
category:             Network
abi:                  ead9632279bfd7c6017fdd83cfc9a4da
exposed:              True
exposed-modules:
    Network.Socks5 Network.Socks5.Lowlevel Network.Socks5.Types

hidden-modules:
    Network.Socks5.Wire Network.Socks5.Conf Network.Socks5.Command
    Network.Socks5.Parse

import-dirs:          /usr/lib/ghc-9.6.6/site-local/socks-0.6.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/socks-0.6.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/socks-0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-socks
hs-libraries:         HSsocks-0.6.1-JuyQtPcZcFFLRHOWXu2EAp
depends:
    base-4.18.2.1 basement-0.0.16-HvTgG10TboKKpCgs2TlMDx
    bytestring-0.11.5.3 cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    network-3.1.4.0-Kxe15bkS84aBmhotDoAJWo

haddock-interfaces:   /usr/share/doc/haskell-socks/html/socks.haddock
haddock-html:         /usr/share/doc/haskell-socks/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
